﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Data;

namespace DataValidation
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }

        private void Validate( object sender, RoutedEventArgs e )
        {
            // do some work

            // validate explicitly  
            BindingExpression be = this.LikesSilverlightCombo.GetBindingExpression( ComboBox.SelectedItemProperty );
            be.UpdateSource();

            List<ValidationError> errors = new List<ValidationError>();

            foreach ( UIElement ui in this.LayoutRoot.Children )
            {
                if ( (ui as FrameworkElement) != null )
                {
                    foreach ( ValidationError error in Validation.GetErrors( ui ) )
                    {
                        errors.Add( error );
                    }
                }
            }

            this.ValidationErrors.ItemsSource = errors;

            if ( errors.Count > 0 )
            {
                this.ValidationSummary.Visibility = Visibility.Visible;
            }
            else
            {
                this.ValidationSummary.Visibility = Visibility.Collapsed;
            }
        }

    }

    public class User
    {
        public string Name
        {
            get { return name; }
            set
            {
                if ( string.IsNullOrEmpty( value ) )
                {
                    throw new Exception( "Please set a value" );
                }

                name = value;
            }
        }

        public bool Gender
        {
            get { return gender; }
            set
            {
                if ( value )
                {
                    throw new Exception( "Only for men. Sorry." );
                }

                gender = value;
            }
        }

        public string LikesSilverlight
        {
            get { return likesSilverlight; }
            set
            {
                if ( !string.IsNullOrEmpty( value ) && value.Equals( "No", StringComparison.OrdinalIgnoreCase ) )
                {
                    throw new Exception( "Really?" );
                }

                likesSilverlight = value;
            }
        }

        public string Attended
        {
            get { return attended; }
            set
            {
                if ( !string.IsNullOrEmpty( value ) && value.Equals( "None", StringComparison.OrdinalIgnoreCase ) )
                {
                    throw new Exception( "You kiddin! Add it to your list for the next year!" );
                }

                attended = value;
            }
        }

        public bool AcceptTerms
        {
            get { return acceptTerms; }
            set
            {
                if ( !value )
                {
                    throw new Exception( "You must accept the terms to continue" );
                }

                acceptTerms = value;
            }
        }

        private string name;
        private bool gender;
        private string likesSilverlight;
        private string attended;
        private bool acceptTerms;
    }
}
